==> kubernetes-model-1.0.58-sources.jar: annotations/io/fabric8/kubernetes/api/model/DeprecatedDownwardAPIVolumeFileBuilder.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
import javax.validation.Validation;
import javax.validation.Validator;
import javax.validation.ValidatorFactory;
import javax.validation.ValidationException;
import javax.validation.ConstraintViolation;
import javax.validation.ConstraintViolationException;
import java.util.Set;
import java.lang.Object;

public class DeprecatedDownwardAPIVolumeFileBuilder extends DeprecatedDownwardAPIVolumeFileFluentImpl<DeprecatedDownwardAPIVolumeFileBuilder> implements VisitableBuilder<DeprecatedDownwardAPIVolumeFile,DeprecatedDownwardAPIVolumeFileBuilder>{

    DeprecatedDownwardAPIVolumeFileFluent<?> fluent;
    Boolean validationEnabled;

    public DeprecatedDownwardAPIVolumeFileBuilder(){
            this(true);
    }
    public DeprecatedDownwardAPIVolumeFileBuilder(Boolean validationEnabled){
            this(new DeprecatedDownwardAPIVolumeFile(), validationEnabled);
    }
    public DeprecatedDownwardAPIVolumeFileBuilder(DeprecatedDownwardAPIVolumeFileFluent<?> fluent){
            this(fluent, true);
    }
    public DeprecatedDownwardAPIVolumeFileBuilder(DeprecatedDownwardAPIVolumeFileFluent<?> fluent,Boolean validationEnabled){
            this(fluent, new DeprecatedDownwardAPIVolumeFile(), validationEnabled);
    }
    public DeprecatedDownwardAPIVolumeFileBuilder(DeprecatedDownwardAPIVolumeFileFluent<?> fluent,DeprecatedDownwardAPIVolumeFile instance){
            this(fluent, instance, true);
    }
    public DeprecatedDownwardAPIVolumeFileBuilder(DeprecatedDownwardAPIVolumeFileFluent<?> fluent,DeprecatedDownwardAPIVolumeFile instance,Boolean validationEnabled){
            this.fluent = fluent; 
            fluent.withFieldRef(instance.getFieldRef()); 
            fluent.withName(instance.getName()); 
            fluent.withResourceFieldRef(instance.getResourceFieldRef()); 
            this.validationEnabled = validationEnabled; 
    }
    public DeprecatedDownwardAPIVolumeFileBuilder(DeprecatedDownwardAPIVolumeFile instance){
            this(instance,true);
    }
    public DeprecatedDownwardAPIVolumeFileBuilder(DeprecatedDownwardAPIVolumeFile instance,Boolean validationEnabled){
            this.fluent = this; 
            this.withFieldRef(instance.getFieldRef()); 
            this.withName(instance.getName()); 
            this.withResourceFieldRef(instance.getResourceFieldRef()); 
            this.validationEnabled = validationEnabled; 
    }

    public DeprecatedDownwardAPIVolumeFile build(){
            DeprecatedDownwardAPIVolumeFile buildable = new DeprecatedDownwardAPIVolumeFile(fluent.getFieldRef(),fluent.getName(),fluent.getResourceFieldRef());
            validate(buildable);
            return buildable;
    }

    private <T>void validate(T item){
            if (!validationEnabled) { return; }
            Validator validator = null;
            try {
                ValidatorFactory factory = Validation.buildDefaultValidatorFactory();
                validator = factory.getValidator();
            } catch(ValidationException e) {return;}
            Set<ConstraintViolation<T>> violations = validator.validate(item);
            if (!violations.isEmpty()) {
            throw new ConstraintViolationException(violations);
             }
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            DeprecatedDownwardAPIVolumeFileBuilder that = (DeprecatedDownwardAPIVolumeFileBuilder) o;
            if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

            if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
            return true;
    }




}

==> kubernetes-model-1.0.65-sources.jar: annotations/io/fabric8/kubernetes/api/model/DeprecatedDownwardAPIVolumeFileBuilder.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class DeprecatedDownwardAPIVolumeFileBuilder extends DeprecatedDownwardAPIVolumeFileFluentImpl<DeprecatedDownwardAPIVolumeFileBuilder> implements VisitableBuilder<DeprecatedDownwardAPIVolumeFile,DeprecatedDownwardAPIVolumeFileBuilder>{

    DeprecatedDownwardAPIVolumeFileFluent<?> fluent;
    Boolean validationEnabled;

    public DeprecatedDownwardAPIVolumeFileBuilder(){
            this(true);
    }
    public DeprecatedDownwardAPIVolumeFileBuilder(Boolean validationEnabled){
            this(new DeprecatedDownwardAPIVolumeFile(), validationEnabled);
    }
    public DeprecatedDownwardAPIVolumeFileBuilder(DeprecatedDownwardAPIVolumeFileFluent<?> fluent){
            this(fluent, true);
    }
    public DeprecatedDownwardAPIVolumeFileBuilder(DeprecatedDownwardAPIVolumeFileFluent<?> fluent,Boolean validationEnabled){
            this(fluent, new DeprecatedDownwardAPIVolumeFile(), validationEnabled);
    }
    public DeprecatedDownwardAPIVolumeFileBuilder(DeprecatedDownwardAPIVolumeFileFluent<?> fluent,DeprecatedDownwardAPIVolumeFile instance){
            this(fluent, instance, true);
    }
    public DeprecatedDownwardAPIVolumeFileBuilder(DeprecatedDownwardAPIVolumeFileFluent<?> fluent,DeprecatedDownwardAPIVolumeFile instance,Boolean validationEnabled){
            this.fluent = fluent; 
            fluent.withFieldRef(instance.getFieldRef()); 
            fluent.withMode(instance.getMode()); 
            fluent.withName(instance.getName()); 
            fluent.withResourceFieldRef(instance.getResourceFieldRef()); 
            this.validationEnabled = validationEnabled; 
    }
    public DeprecatedDownwardAPIVolumeFileBuilder(DeprecatedDownwardAPIVolumeFile instance){
            this(instance,true);
    }
    public DeprecatedDownwardAPIVolumeFileBuilder(DeprecatedDownwardAPIVolumeFile instance,Boolean validationEnabled){
            this.fluent = this; 
            this.withFieldRef(instance.getFieldRef()); 
            this.withMode(instance.getMode()); 
            this.withName(instance.getName()); 
            this.withResourceFieldRef(instance.getResourceFieldRef()); 
            this.validationEnabled = validationEnabled; 
    }

    public DeprecatedDownwardAPIVolumeFile build(){
            DeprecatedDownwardAPIVolumeFile buildable = new DeprecatedDownwardAPIVolumeFile(fluent.getFieldRef(),fluent.getMode(),fluent.getName(),fluent.getResourceFieldRef());
            io.fabric8.kubernetes.api.builder.ValidationUtils.validate(buildable);
            return buildable;
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            DeprecatedDownwardAPIVolumeFileBuilder that = (DeprecatedDownwardAPIVolumeFileBuilder) o;
            if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

            if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
            return true;
    }




}
